@@ -32,10 +32,18 @@ class ExcoBlockContainsExtraKey(ExcoException):
     pass
 
 
+class ActorCreationFailException(ExcoException):
+    pass
+
+
 class ParserCreationFailException(ExcoException):
     pass
 
 
+class ParserSpecCreationException(ExcoException):
+    pass
+
+
 class ParsingFailException(ExcoException):
     pass
 
@@ -46,3 +54,31 @@ class ExtractionTaskCreationException(ExcoException):
 
 class ExcelProcessorCreationException(ExcoException):
     pass
+
+
+class TooManyRowRead(ExcoException):
+    pass
+
+
+class TableKeyNotFound(ExcoException):
+    pass
+
+
+class TableHasNoColumn(ExcoException):
+    pass
+
+
+class MissingTableBlock(ExcoException):
+    pass
+
+
+class TableExtractionTaskCreationException(ExcoException):
+    pass
+
+
+class NoEndConditionError(ExcoException):
+    pass
+
+
+class YamlParseError(ExcoException):
+    pass
