@@ -13,7 +13,7 @@ class LocatorFactory(BaseFactory[Locator, LocatorSpec]):
         super().__init__(class_map)
 
     @classmethod
-    def suffix(self):
+    def suffix(cls):
         return 'Locator'
 
     @classmethod
