@@ -1,7 +1,8 @@
 from typing import Dict, Type
 
-from exco.extraction_spec.parser_spec import ParserSpec
+from exco.extractor_spec.parser_spec import ParserSpec
 from exco.extractor.base_factory import BaseFactory
+from exco.extractor.parser.built_in.date_parser import DateParser
 from exco.extractor.parser.parser import Parser
 from exco.extractor.parser.built_in.string_parser import StringParser
 from exco.extractor.parser.built_in.int_parser import IntParser
@@ -13,7 +14,7 @@ class ParserFactory(BaseFactory[Parser, ParserSpec]):
         super().__init__(class_map)
 
     @classmethod
-    def suffix(self):
+    def suffix(cls):
         return 'Parser'
 
     @classmethod
@@ -21,5 +22,6 @@ class ParserFactory(BaseFactory[Parser, ParserSpec]):
         return cls(cls.build_class_dict([
             IntParser,
             StringParser,
-            FloatParser
+            FloatParser,
+            DateParser
         ]))
